from .device import device_firmware, device_info, device_type
from .peripherals import (
    legacy_pitop_peripherals,
    pitop_keyboard_is_connected,
    pitop_peripherals,
    touchscreen_is_connected,
    upgradable_pitop_peripherals,
    usb_pitop_peripherals,
)
